# Kara - Integrations

## Overview

Integrations are different from Abilities. Imagine it like it this, Abilities give
Kara functionality and allow her to perform and control new commands.
Integrations allow Kara to work inside of your project and hand the controller
over to it too. This means you can have greater control of how she performs tasks.

## Developers Guide

Integrations are different from Abilities and should not be confused. Imagine it
like it this, Abilities give Kara functionality and allow her to perform and
control new commands. Integrations allow Kara to work inside of your project and
hand the controller over to it too. This means you can have greater control of
how she performs tasks.
